<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>BusyIndicatorSpecifics</name>
    <message>
        <source>Busy Indicator</source>
        <translation>Індикатор зайнятості</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Виконується</translation>
    </message>
    <message>
        <source>Whether the busy indicator is currently indicating activity.</source>
        <translation>Чи індикатор показує зайнятість зараз.</translation>
    </message>
</context>
<context>
    <name>ButtonSection</name>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>The text displayed on the %1.</source>
        <translation>Текст, що відображується на %1.</translation>
    </message>
    <message>
        <source>Highlighted</source>
        <translation>Підсвічувати</translation>
    </message>
    <message>
        <source>Whether the %1 is highlighted.</source>
        <translation>Чи %1 підсвічено.</translation>
    </message>
    <message>
        <source>Checkable</source>
        <translation>Можна відмічати</translation>
    </message>
    <message>
        <source>Whether the %1 is checkable.</source>
        <translation>Чи %1 можна відмічати.</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Відмічено</translation>
    </message>
    <message>
        <source>Whether the %1 is checked.</source>
        <translation>Чи %1 відмічено.</translation>
    </message>
    <message>
        <source>Exclusive</source>
        <translation>Ексклюзивно</translation>
    </message>
    <message>
        <source>Whether the %1 is exclusive.</source>
        <translation>Чи %1 відмічено ексклюзивно.</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Повторення</translation>
    </message>
    <message>
        <source>Whether the %1 repeats while pressed and held down.</source>
        <translation>Чи %1 повторюється, коли натиснено і утримується.</translation>
    </message>
</context>
<context>
    <name>ButtonSpecifics</name>
    <message>
        <source>Button</source>
        <translation>Кнопка</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Текст</translation>
    </message>
    <message>
        <source>The text displayed on the button.</source>
        <translation type="vanished">Текст, що відображується на кнопці.</translation>
    </message>
</context>
<context>
    <name>CheckBoxSpecifics</name>
    <message>
        <source>Check Box</source>
        <translation>Прапорець</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Текст</translation>
    </message>
    <message>
        <source>The text displayed on the check box.</source>
        <translation type="vanished">Текст, що відображується на прапорці.</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation type="vanished">Відмічено</translation>
    </message>
    <message>
        <source>The checked state of the check box.</source>
        <translation type="vanished">Стан відміченості прапорця.</translation>
    </message>
</context>
<context>
    <name>ComboBoxSpecifics</name>
    <message>
        <source>Combo Box</source>
        <translation>Випадаючий список</translation>
    </message>
    <message>
        <source>Text Role</source>
        <translation>Роль для тексту</translation>
    </message>
    <message>
        <source>The model role used for displaying text.</source>
        <translation>Роль моделі, що використовується для відображення тексту.</translation>
    </message>
    <message>
        <source>Current</source>
        <translation>Поточний</translation>
    </message>
    <message>
        <source>The index of the current item.</source>
        <translation>Номер поточного елементу.</translation>
    </message>
</context>
<context>
    <name>ControlSection</name>
    <message>
        <source>Control</source>
        <translation>Елемент управління</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <source>Whether the control is enabled.</source>
        <translation>Чи елемент управління увімкнено.</translation>
    </message>
    <message>
        <source>Spacing</source>
        <translation>Відступ</translation>
    </message>
    <message>
        <source>Spacing between internal elements of the control.</source>
        <translation>Відступ між внутрішніми частинами елемента управління.</translation>
    </message>
</context>
<context>
    <name>DefaultColorDialog</name>
    <message>
        <source>Hue</source>
        <translation type="vanished">Відтінок</translation>
    </message>
    <message>
        <source>Saturation</source>
        <translation type="vanished">Насиченість</translation>
    </message>
    <message>
        <source>Luminosity</source>
        <translation type="vanished">Світність</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="vanished">Альфа</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Скасувати</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
</context>
<context>
    <name>DefaultDialogWrapper</name>
    <message>
        <source>Show Details...</source>
        <translation type="vanished">Показати деталі...</translation>
    </message>
</context>
<context>
    <name>DefaultFileDialog</name>
    <message>
        <source>Go up to the folder containing this one</source>
        <translation type="vanished">Перейти нагору до теки, що містить цю</translation>
    </message>
    <message>
        <source>Remove favorite</source>
        <translation type="vanished">Видалити улюблену</translation>
    </message>
    <message>
        <source>Add the current directory as a favorite</source>
        <translation type="vanished">Додати поточну теку як улюблену</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="vanished">Назва файлу</translation>
    </message>
    <message>
        <source>Type</source>
        <comment>file type (extension)</comment>
        <translation type="vanished">Тип</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>file size</comment>
        <translation type="vanished">Розмір</translation>
    </message>
    <message>
        <source>Modified</source>
        <comment>last-modified time</comment>
        <translation type="vanished">Змінено</translation>
    </message>
    <message>
        <source>Accessed</source>
        <comment>last-accessed time</comment>
        <translation type="vanished">Доступ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Скасувати</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation type="vanished">Вибір</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="vanished">Відкрити</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Зберегти</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
</context>
<context>
    <name>DefaultFontDialog</name>
    <message>
        <source>Writing System</source>
        <translation type="vanished">Система письма</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Шрифт</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="vanished">Розмір</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation type="vanished">Жирність</translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="vanished">Стиль</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation type="vanished">Приклад</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Курсив</translation>
    </message>
    <message>
        <source>Font Family</source>
        <translation type="vanished">Родина шрифтів</translation>
    </message>
    <message>
        <source>Thin</source>
        <translation type="vanished">Тонкий</translation>
    </message>
    <message>
        <source>ExtraLight</source>
        <translation type="vanished">Надлегкий</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Легкий</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="vanished">Нормальний</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="vanished">Середні</translation>
    </message>
    <message>
        <source>DemiBold</source>
        <translation type="vanished">Напівжирний</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Жирний</translation>
    </message>
    <message>
        <source>ExtraBold</source>
        <translation type="vanished">Наджирний</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Чорний</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="vanished">Підкреслений</translation>
    </message>
    <message>
        <source>Overline</source>
        <translation type="vanished">Надкреслений</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation type="vanished">Перекреслений</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Скасувати</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
</context>
<context>
    <name>DefaultMessageDialog</name>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="vanished">Відкрити</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Зберегти</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="vanished">Зберегти все</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Повторити</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="vanished">Ігнорувати</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Застосувати</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Так</translation>
    </message>
    <message>
        <source>Yes to All</source>
        <translation type="vanished">Так для всіх</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">Ні</translation>
    </message>
    <message>
        <source>No to All</source>
        <translation type="vanished">Ні для всіх</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="vanished">Відкинути</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="vanished">Скинути</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="vanished">Відновити типові</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Скасувати</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="vanished">Перервати</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Закрити</translation>
    </message>
    <message>
        <source>Show Details...</source>
        <translation type="vanished">Показати деталі...</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Довідка</translation>
    </message>
    <message>
        <source>Hide Details</source>
        <translation type="vanished">Сховати деталі</translation>
    </message>
</context>
<context>
    <name>DialSpecifics</name>
    <message>
        <source>Dial</source>
        <translation>Набирач</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значення</translation>
    </message>
    <message>
        <source>The current value of the dial.</source>
        <translation>Поточне значення набирача.</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <source>The starting value of the dial range.</source>
        <translation>Початкове значення набирача.</translation>
    </message>
    <message>
        <source>To</source>
        <translation>До</translation>
    </message>
    <message>
        <source>The ending value of the dial range.</source>
        <translation>Кінцеве значення набирача.</translation>
    </message>
    <message>
        <source>Step Size</source>
        <translation>Розмір кроку</translation>
    </message>
    <message>
        <source>The step size of the dial.</source>
        <translation>Розмір кроку набирача.</translation>
    </message>
</context>
<context>
    <name>EditMenu_base</name>
    <message>
        <source>&amp;Undo</source>
        <translation type="vanished">&amp;Повернути</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation type="vanished">П&amp;овторити</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">Ви&amp;різати</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="vanished">&amp;Копіювати</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="vanished">&amp;Вставити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Видалити</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="vanished">Очистити</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="vanished">Вибрати все</translation>
    </message>
</context>
<context>
    <name>EditMenu_ios</name>
    <message>
        <source>Cut</source>
        <translation type="vanished">Вирізати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Копіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Вставити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Видалити</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">Вибрати</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="vanished">Вибрати все</translation>
    </message>
</context>
<context>
    <name>GroupBoxSpecifics</name>
    <message>
        <source>Group Box</source>
        <translation>Контейнер</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <source>The title of the group box.</source>
        <translation>Заголовок контейнера.</translation>
    </message>
</context>
<context>
    <name>PaddingSection</name>
    <message>
        <source>Padding</source>
        <translation>Доповнення</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Згори</translation>
    </message>
    <message>
        <source>Padding between the content and the top edge of the control.</source>
        <translation>Доповнення між змістом та верхнім краєм елемента управління.</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Зліва</translation>
    </message>
    <message>
        <source>Padding between the content and the left edge of the control.</source>
        <translation>Доповнення між змістом та лівим краєм елемента управління.</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Padding between the content and the right edge of the control.</source>
        <translation>Доповнення між змістом та правим краєм елемента управління.</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Знизу</translation>
    </message>
    <message>
        <source>Padding between the content and the bottom edge of the control.</source>
        <translation>Доповнення між змістом та нижнім краєм елемента управління.</translation>
    </message>
</context>
<context>
    <name>PageIndicatorSpecifics</name>
    <message>
        <source>Indicator</source>
        <translation>Індикатор</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Кількість</translation>
    </message>
    <message>
        <source>The number of pages.</source>
        <translation>Кількість сторінок.</translation>
    </message>
    <message>
        <source>Current</source>
        <translation>Поточна</translation>
    </message>
    <message>
        <source>The index of the current page.</source>
        <translation>Номер поточної сторінки.</translation>
    </message>
    <message>
        <source>The index of the current page</source>
        <translation type="vanished">Номер поточної сторінки</translation>
    </message>
</context>
<context>
    <name>ProgressBarSpecifics</name>
    <message>
        <source>Progress Bar</source>
        <translation>Панель прогресу</translation>
    </message>
    <message>
        <source>Indeterminate</source>
        <translation>Невизначено</translation>
    </message>
    <message>
        <source>Whether the progress is indeterminate.</source>
        <translation>Чи є прогрес невизначетим.</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значення</translation>
    </message>
    <message>
        <source>The current value of the progress.</source>
        <translation>Поточне значення прогресу.</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <source>The starting value for the progress.</source>
        <translation>Початкове значення прогресу.</translation>
    </message>
    <message>
        <source>To</source>
        <translation>До</translation>
    </message>
    <message>
        <source>The ending value for the progress.</source>
        <translation>Кінцеве значення прогресу.</translation>
    </message>
</context>
<context>
    <name>QtLabsMaterialStylePlugin</name>
    <message>
        <source>Material is an attached property</source>
        <translation type="vanished">Material є прикріпленою властивістю</translation>
    </message>
</context>
<context>
    <name>QtLabsUniversalStylePlugin</name>
    <message>
        <source>Universal is an attached property</source>
        <translation type="vanished">Universal є прикріпленою властивістю</translation>
    </message>
</context>
<context>
    <name>QtQuickControls2MaterialStylePlugin</name>
    <message>
        <source>Material is an attached property</source>
        <translation>Material є прикріпленою властивістю</translation>
    </message>
</context>
<context>
    <name>QtQuickControls2UniversalStylePlugin</name>
    <message>
        <source>Universal is an attached property</source>
        <translation>Universal є прикріпленою властивістю</translation>
    </message>
</context>
<context>
    <name>RadioButtonSpecifics</name>
    <message>
        <source>Radio Button</source>
        <translation>Перемикач</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Текст</translation>
    </message>
    <message>
        <source>The text displayed on the radio button.</source>
        <translation type="vanished">Текст, що відображується на перемикачі.</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation type="vanished">Відмічено</translation>
    </message>
    <message>
        <source>The checked state of the radio button.</source>
        <translation type="vanished">Стан відміченості перемикача.</translation>
    </message>
</context>
<context>
    <name>SliderSpecifics</name>
    <message>
        <source>Slider</source>
        <translation>Повзунок</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значення</translation>
    </message>
    <message>
        <source>The current value of the slider.</source>
        <translation>Поточне значення повзунка.</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <source>The starting value of the slider range.</source>
        <translation>Початкове значення повзунка.</translation>
    </message>
    <message>
        <source>To</source>
        <translation>До</translation>
    </message>
    <message>
        <source>The ending value of the slider range.</source>
        <translation>Кінцеве значення повзунка.</translation>
    </message>
    <message>
        <source>Step Size</source>
        <translation>Розмір кроку</translation>
    </message>
    <message>
        <source>Step size</source>
        <translation type="vanished">Розмір кроку</translation>
    </message>
    <message>
        <source>The step size of the slider.</source>
        <translation>Розмір кроку повзунка.</translation>
    </message>
    <message>
        <source>Orientation</source>
        <translation>Орієнтація</translation>
    </message>
    <message>
        <source>The orientation of the slider.</source>
        <translation>Орієнтація повзунка.</translation>
    </message>
</context>
<context>
    <name>SpinBoxSpecifics</name>
    <message>
        <source>Spin Box</source>
        <translation>Лічильник</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значення</translation>
    </message>
    <message>
        <source>The current value of the spinbox.</source>
        <translation>Поточне значення лічильника.</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <source>The starting value of the spinbox range.</source>
        <translation>Початкове значення лічильника.</translation>
    </message>
    <message>
        <source>To</source>
        <translation>До</translation>
    </message>
    <message>
        <source>The ending value of the spinbox range.</source>
        <translation>Кінцеве значення лічильника.</translation>
    </message>
    <message>
        <source>Step Size</source>
        <translation>Розмір кроку</translation>
    </message>
    <message>
        <source>The step size of the spinbox.</source>
        <translation>Розмір кроку лічильника.</translation>
    </message>
</context>
<context>
    <name>SwitchSpecifics</name>
    <message>
        <source>Switch</source>
        <translation>Вмикач</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Текст</translation>
    </message>
    <message>
        <source>The text displayed on the switch.</source>
        <translation type="vanished">Текст, що відображується на вмикачі.</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation type="vanished">Відмічено</translation>
    </message>
    <message>
        <source>The checked state of the switch.</source>
        <translation type="vanished">Стан відміченості вмикача.</translation>
    </message>
</context>
<context>
    <name>ToolButtonSpecifics</name>
    <message>
        <source>Tool Button</source>
        <translation>Кнопка панелі інструментів</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Текст</translation>
    </message>
    <message>
        <source>The text displayed on the tool button.</source>
        <translation type="vanished">Текст, що відображується на кнопці.</translation>
    </message>
</context>
<context>
    <name>TumblerSpecifics</name>
    <message>
        <source>Tumbler</source>
        <translation>Тумблер</translation>
    </message>
    <message>
        <source>Visible Count</source>
        <translation>Видима кількість</translation>
    </message>
    <message>
        <source>The count of visible items.</source>
        <translation>Кількість видимих елементів.</translation>
    </message>
    <message>
        <source>Current</source>
        <translation>Поточний</translation>
    </message>
    <message>
        <source>The index of the current item.</source>
        <translation>Номер поточного елементу.</translation>
    </message>
</context>
</TS>
